@@ -150,6 +150,7 @@ class _IOFile(str):
     __slots__ = ["_is_function", "_file", "rule", "_regex"]
 
     def __new__(cls, file):
+        # Remove trailing slashes.
         obj = str.__new__(cls, file)
         obj._is_function = isfunction(file) or ismethod(file)
         obj._is_function = obj._is_function or (
@@ -169,10 +170,11 @@ class _IOFile(str):
         def wrapper(self, *args, **kwargs):
             if self.rule.workflow.iocache.active:
                 cache = getattr(self.rule.workflow.iocache, func.__name__)
-                if self in cache:
-                    return cache[self]
+                normalized = self.rstrip("/")
+                if normalized in cache:
+                    return cache[normalized]
                 v = func(self, *args, **kwargs)
-                cache[self] = v
+                cache[normalized] = v
                 return v
             else:
                 return func(self, *args, **kwargs)
@@ -217,12 +219,14 @@ class _IOFile(str):
             queue = [root]
             while queue:
                 path = queue.pop(0)
+                # path must be a dir
                 cache.exists_local[path] = True
                 with os.scandir(path) as scan:
                     for entry in scan:
                         if entry.is_dir():
                             queue.append(entry.path)
                         else:
+                            # path is a file
                             cache.exists_local[entry.path] = True
 
         cache.has_inventory.add(root)
@@ -951,7 +955,7 @@ def expand(*args, **wildcards):
         combinator = product
     elif len(args) == 2:
         combinator = args[1]
-    if isinstance(filepatterns, str):
+    if isinstance(filepatterns, str) or isinstance(filepatterns, Path):
         filepatterns = [filepatterns]
 
     def path_to_str(f):
@@ -1261,8 +1265,8 @@ class Namedlist(list):
         these functions should not be used.        
         """
         raise AttributeError(
-            f"{_name}() cannot be used; attribute name reserved"
-            f" for use in some existing workflows"
+            "{_name}() cannot be used; attribute name reserved"
+            " for use in some existing workflows".format(_name=_name)
         )
 
     def _add_name(self, name):
@@ -1284,8 +1288,8 @@ class Namedlist(list):
         """
         if name not in self._allowed_overrides and hasattr(self.__class__, name):
             raise AttributeError(
-                f"invalid name for input, output, wildcard, "
-                f"params or log: {name} is reserved for internal use"
+                "invalid name for input, output, wildcard, "
+                "params or log: {name} is reserved for internal use".format(name=name)
             )
 
         self._names[name] = (index, end)
