@@ -14,6 +14,7 @@ from contextlib import contextmanager
 from snakemake.remote import AbstractRemoteProvider, DomainObject
 from snakemake.exceptions import HTTPFileException, WorkflowError
 from snakemake.logging import logger
+from snakemake.utils import os_sync
 
 
 try:
@@ -231,7 +232,7 @@ class RemoteObject(DomainObject):
                     os.makedirs(os.path.dirname(self.local_path), exist_ok=True)
                     with open(self.local_path, "wb") as f:
                         shutil.copyfileobj(httpr.raw, f)
-                    os.sync()  # ensure flush to disk
+                    os_sync()  # ensure flush to disk
             else:
                 raise HTTPFileException(
                     "The file does not seem to exist remotely: %s" % self.remote_file()
