@@ -9,6 +9,7 @@ from contextlib import contextmanager
 # module-specific
 from snakemake.remote import AbstractRemoteProvider, DomainObject
 from snakemake.exceptions import SFTPFileException, WorkflowError
+from snakemake.utils import os_sync
 
 try:
     # third-party modules
@@ -139,7 +140,7 @@ class RemoteObject(DomainObject):
                     localpath=self.local_path,
                     preserve_mtime=True,
                 )
-                os.sync()  # ensure flush to disk
+                os_sync()  # ensure flush to disk
             else:
                 raise SFTPFileException(
                     "The file does not seem to exist remotely: %s" % self.local_file()
