@@ -167,6 +167,14 @@ class AbstractRemoteObject:
         self.provider = provider
         self.protocol = protocol
 
+    def inventory(self, cache: snakemake.io.IOCache):
+        """From this file, try to find as much existence and modification date 
+        information as possible.
+        """
+        # If this is implemented in a remote object, results have to be stored in
+        # the given IOCache object.
+        pass
+
     @property
     def _file(self):
         if self._iofile is None:
