@@ -11,6 +11,7 @@ import functools
 # module-specific
 from snakemake.remote import AbstractRemoteProvider, AbstractRemoteObject, DomainObject
 from snakemake.exceptions import WebDAVFileException, WorkflowError
+from snakemake.utils import os_sync
 
 try:
     # third-party modules
@@ -150,7 +151,7 @@ class RemoteObject(DomainObject):
                 self.loop.run_until_complete(
                     self.conn.download(self.webdav_file, self.local_file())
                 )
-                os.sync()  # ensure flush to disk
+                os_sync()  # ensure flush to disk
         else:
             raise WorkflowError(
                 "The file does not seem to exist remotely: %s" % self.webdav_file
