@@ -20,6 +20,7 @@ from snakemake.executors import (
     KubernetesExecutor,
     TibannaExecutor,
 )
+from snakemake.executors.google_lifesciences import GoogleLifeSciencesExecutor
 from snakemake.exceptions import RuleException, WorkflowError, print_exception
 from snakemake.shell import shell
 
@@ -64,6 +65,10 @@ class JobScheduler:
         container_image=None,
         tibanna=None,
         tibanna_sfn=None,
+        google_lifesciences=None,
+        google_lifesciences_regions=None,
+        google_lifesciences_location=None,
+        google_lifesciences_cache=False,
         precommand="",
         tibanna_config=False,
         jobname=None,
@@ -260,6 +265,32 @@ class JobScheduler:
                 latency_wait=latency_wait,
                 keepincomplete=keepincomplete,
             )
+        elif google_lifesciences:
+            self._local_executor = CPUExecutor(
+                workflow,
+                dag,
+                local_cores,
+                printreason=printreason,
+                quiet=quiet,
+                printshellcmds=printshellcmds,
+                latency_wait=latency_wait,
+                cores=local_cores,
+            )
+
+            self._executor = GoogleLifeSciencesExecutor(
+                workflow,
+                dag,
+                cores,
+                container_image=container_image,
+                regions=google_lifesciences_regions,
+                location=google_lifesciences_location,
+                cache=google_lifesciences_cache,
+                printreason=printreason,
+                quiet=quiet,
+                printshellcmds=printshellcmds,
+                latency_wait=latency_wait,
+            )
+
         else:
             self._executor = CPUExecutor(
                 workflow,
@@ -309,7 +340,6 @@ class JobScheduler:
 
     def schedule(self):
         """ Schedule jobs that are ready, maximizing cpu usage. """
-
         try:
             while True:
                 # work around so that the wait does not prevent keyboard interrupts
@@ -372,10 +402,12 @@ class JobScheduler:
                 # update running jobs
                 with self._lock:
                     self.running.update(run)
+
                 # actually run jobs
-                for job in run:
-                    with self.rate_limiter:
-                        self.run(job)
+                local_runjobs = [job for job in run if job.is_local]
+                runjobs = [job for job in run if not job.is_local]
+                self.run(local_runjobs, executor=self._local_executor or self._executor)
+                self.run(runjobs)
         except (KeyboardInterrupt, SystemExit):
             logger.info(
                 "Terminating processes on user request, this might take some time."
@@ -383,20 +415,21 @@ class JobScheduler:
             self._executor.cancel()
             return False
 
-    def get_executor(self, job):
-        if self._local_executor is None:
-            return self._executor
-        else:
-            return self._local_executor if job.is_local else self._executor
-
-    def run(self, job):
-        self.get_executor(job).run(
-            job,
+    def run(self, jobs, executor=None):
+        if executor is None:
+            executor = self._executor
+        executor.run_jobs(
+            jobs,
             callback=self._finish_callback,
             submit_callback=self._submit_callback,
             error_callback=self._error,
         )
 
+    def get_executor(self, job):
+        if job.is_local and self._local_executor is not None:
+            return self._local_executor
+        return self._executor
+
     def _noop(self, job):
         pass
 
