@@ -19,6 +19,7 @@ from urllib.parse import urljoin
 
 from snakemake.io import regex, Namedlist, Wildcards, _load_configfile
 from snakemake.logging import logger
+from snakemake.common import ON_WINDOWS
 from snakemake.exceptions import WorkflowError
 import snakemake
 
@@ -527,4 +528,30 @@ def argvquote(arg, force=True):
         return cmdline
 
 
-ON_WINDOWS = platform.system() == "Windows"
+def os_sync():
+    """Ensure flush to disk"""
+    if not ON_WINDOWS:
+        os.sync()
+
+
+def _find_bash_on_windows():
+    """
+    Find the path to a usable bash on windows.
+    First attempt is to look for bash installed  with a git conda package. 
+    alternatively try bash installed with 'Git for Windows'.
+    """
+    if not ON_WINDOWS:
+        return None
+    # First look for bash in git's conda package
+    bashcmd = os.path.join(os.path.dirname(sys.executable), r"Library\bin\bash.exe")
+    if not os.path.exists(bashcmd):
+        # Otherwise try bash installed with "Git for Windows".
+        import winreg
+
+        try:
+            key = winreg.OpenKey(winreg.HKEY_LOCAL_MACHINE, "SOFTWARE\\GitForWindows")
+            gfwp, _ = winreg.QueryValueEx(key, "InstallPath")
+            bashcmd = os.path.join(gfwp, "bin\\bash.exe")
+        except FileNotFoundError:
+            bashcmd = ""
+    return bashcmd if os.path.exists(bashcmd) else None
